@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher::AO3;
-$WWW::FetchStory::Fetcher::AO3::VERSION = '0.22';
+$WWW::FetchStory::Fetcher::AO3::VERSION = '0.2201';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher::AO3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.22
+version 0.2201
 
 =head1 DESCRIPTION
 
@@ -437,6 +437,31 @@ sub parse_category {
     {
 	$category = $self->SUPER::parse_category(%args);
     }
+
+    # Also add the "relationship tags", if any, to the categories
+    if ($content =~ m!<dd class="relationship tags">(.*?)</dd>!s)
+    {
+        my $str = $1;
+        my @cats = ($category);
+        while ($str =~ m!([^><]+)</a>!g)
+        {
+            my $rawrel = $1;
+            my $rel = $rawrel;
+            if ($rawrel =~ m!/!)
+            {
+                $rawrel =~ s!/!-!g;
+                $rel = "${rawrel} Romance";
+            }
+            elsif ($rawrel =~ m!\&amp;!)
+            {
+                $rawrel =~ s!\s*\&amp;\s*!-!g;
+                $rel = "${rawrel} Friendship";
+            }
+            push @cats, $rel;
+        }
+        $category = join(', ', @cats);
+    }
+
     return $category;
 } # parse_category
 
